"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parsePath = parsePath;
exports.resolveImage = resolveImage;

var _fs = require("fs");

var _mime = require("mime");

var _path = _interopRequireDefault(require("path"));

var _util = require("util");

var _WebpConverter = require("./WebpConverter");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const statAsync = (0, _util.promisify)(_fs.stat);
const readFileAsync = (0, _util.promisify)(_fs.readFile);

function parsePath(resourcePath) {
  var _match$;

  // https://regexr.com/54acj
  const match = resourcePath.match(/^(?:(.*)[\\/])?([^\\/]+?)(?:@([0-9])x)?\.(.+)$/);

  if (!match || !match[2] || !match[4]) {
    throw new Error(`Unable to parse resource ${resourcePath}.`);
  }

  return {
    dir: (_match$ = match[1]) !== null && _match$ !== void 0 ? _match$ : '',
    name: match[2],
    scale: match[3] != null ? parseFloat(match[3]) : 1,
    ext: match[4]
  };
}

async function resolveImage(resourcePath, resourceContent, scales) {
  const fileData = parsePath(resourcePath);
  const type = (0, _mime.getType)(fileData.ext);

  if (type == null) {
    throw new Error(`Unable to parse mime type for ${resourcePath}.`);
  }

  const generateWebp = type === 'image/png' || type === 'image/jpeg';
  const result = [];

  const getFilePath = scale => {
    const suffix = scale === 1 ? '' : `@${scale}x`;
    return _path.default.join(fileData.dir, `${fileData.name}${suffix}.${fileData.ext}`);
  };

  const addFile = async (scale, content) => {
    const filePath = getFilePath(scale);
    result.push({
      uri: filePath,
      content,
      scale,
      type
    });

    if (generateWebp) {
      const webpContent = await (0, _WebpConverter.convertToWebp)(content);
      result.push({
        uri: filePath.replace(/\.png|\.jpe?g/, '.webp'),
        content: webpContent,
        scale,
        type: 'image/webp'
      });
    }
  }; // Original file will be passed as `resourceContent`.


  await addFile(fileData.scale, resourceContent); // Find other files available for scales.

  const missingScales = scales.filter(s => s !== fileData.scale);

  for (const scale of missingScales) {
    try {
      const filePath = getFilePath(scale);
      const stats = await statAsync(filePath);

      if (stats.isFile()) {
        const content = await readFileAsync(filePath);
        await addFile(scale, content);
      }
    } catch (e) {// Do nothing
    }
  }

  return result;
}
//# sourceMappingURL=ImageResolver.js.map